SpanSelector widget can now be snapped to specified values
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
The SpanSelector widget can now be snapped to values specified by the *snap_values*
argument.
